@@ -5,9 +5,16 @@
 #include <QNetworkReply>
 #include <QStringList>
 #include <QDebug>
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 #ifdef QML_USER_INTERFACE
+#if QT_VERSION >= 0x050000
+#include <QQmlEngine>
+#else
 #include <QDeclarativeEngine>
 #endif
+#endif
 
 using namespace QtJson;
 
@@ -52,17 +59,16 @@ Dailymotion* Dailymotion::instance() {
 void Dailymotion::setBusy(bool isBusy, const QString &message, int numberOfOperations) {
     if (isBusy != this->busy()) {
         m_busy = isBusy;
-
-        if (isBusy) {
-            this->setCancelled(false);
-            emit busy(message, numberOfOperations);
-        }
-        else if (!this->cancelled()) {
-            emit busyProgressChanged(numberOfOperations);
-        }
-
         emit busyChanged(isBusy);
     }
+
+    if (isBusy) {
+        this->setCancelled(false);
+        emit busy(message, numberOfOperations);
+    }
+    else if (!this->cancelled()) {
+        emit busyProgressChanged(numberOfOperations);
+    }
 }
 
 void Dailymotion::cancelCurrentOperation() {
@@ -80,6 +86,20 @@ void Dailymotion::cancelCurrentOperation() {
 }
 
 QNetworkReply* Dailymotion::createReply(QUrl feed, int offset) {
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(feed);
+
+    if (userSignedIn()) {
+        query.addQueryItem("access_token", this->accessToken());
+    }
+
+    if (offset) {
+        query.addQueryItem("page", QString::number(offset));
+    }
+
+    query.addQueryItem("family_filter", this->safeSearch() ? "true" : "false");
+    feed.setQuery(query);
+#else
     if (userSignedIn()) {
         feed.addQueryItem("access_token", this->accessToken());
     }
@@ -89,6 +109,7 @@ QNetworkReply* Dailymotion::createReply(QUrl feed, int offset) {
     }
 
     feed.addQueryItem("family_filter", this->safeSearch() ? "true" : "false");
+#endif
 
     qDebug() << feed;
 
@@ -100,7 +121,49 @@ QNetworkReply* Dailymotion::createReply(QUrl feed, int offset) {
 
 QNetworkReply* Dailymotion::createSearchReply(int queryType, const QString &query, int offset, int order, const QString &language) {
     QUrl url;
+#if QT_VERSION >= 0x050000
+    QUrlQuery urlQuery;
 
+    switch (queryType) {
+    case Queries::Videos:
+        url.setUrl(DAILYMOTION_VIDEOS_BASE_URL);
+        urlQuery.addQueryItem("fields", DAILYMOTION_VIDEO_FIELDS);
+        urlQuery.addQueryItem("sort", m_queryOrders.value(order, "relevance"));
+
+        if ((!language.isEmpty()) && (language != "all")) {
+            urlQuery.addQueryItem("localization", language);
+        }
+        break;
+    case Queries::Playlists:
+        url.setUrl(DAILYMOTION_PLAYLISTS_BASE_URL);
+        urlQuery.addQueryItem("fields", DAILYMOTION_PLAYLIST_FIELDS);
+        urlQuery.addQueryItem("sort", "relevance");
+        break;
+    case Queries::Users:
+        url.setUrl(DAILYMOTION_USERS_BASE_URL);
+        urlQuery.addQueryItem("fields", DAILYMOTION_USER_FIELDS);
+        urlQuery.addQueryItem("sort", "relevance");
+        break;
+    case Queries::Groups:
+        url.setUrl(DAILYMOTION_GROUPS_BASE_URL);
+        urlQuery.addQueryItem("fields", DAILYMOTION_GROUP_FIELDS);
+        urlQuery.addQueryItem("sort", "relevance");
+        break;
+    default:
+        qWarning() << "Dailymotion::createSearchReply(): No/invalid query type.";
+        break;
+    }
+
+    urlQuery.addQueryItem("family_filter", this->safeSearch() ? "true" : "false");
+    urlQuery.addQueryItem("limit", "30");
+    urlQuery.addQueryItem("search", QString("\"%1\"|%2").arg(query).arg(query.simplified().replace(' ', '+')));
+
+    if (offset) {
+        urlQuery.addQueryItem("page", QString::number(offset));
+    }
+
+    url.setQuery(urlQuery);
+#else
     switch (queryType) {
     case Queries::Videos:
         url.setUrl(DAILYMOTION_VIDEOS_BASE_URL);
@@ -138,7 +201,7 @@ QNetworkReply* Dailymotion::createSearchReply(int queryType, const QString &quer
     if (offset) {
         url.addQueryItem("page", QString::number(offset));
     }
-
+#endif
     qDebug() << url;
 
     QNetworkRequest request(url);
@@ -149,12 +212,21 @@ QNetworkReply* Dailymotion::createSearchReply(int queryType, const QString &quer
 
 QUrl Dailymotion::authUrl() const {
     QUrl url("https://api.dailymotion.com/oauth/authorize");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("client_id", CLIENT_ID);
+    query.addQueryItem("response_type", "code");
+    query.addQueryItem("redirect_uri", REDIRECT_URI);
+    query.addQueryItem("display", "mobile");
+    query.addQueryItem("scope", "read+userinfo+manage_videos+manage_comments+manage_playlists+manage_subscriptions+manage_favorites+manage_groups");
+    url.setQuery(query);
+#else
     url.addQueryItem("client_id", CLIENT_ID);
     url.addQueryItem("response_type", "code");
     url.addQueryItem("redirect_uri", REDIRECT_URI);
     url.addQueryItem("display", "mobile");
     url.addQueryItem("scope", "read+userinfo+manage_videos+manage_comments+manage_playlists+manage_subscriptions+manage_favorites+manage_groups");
-
+#endif
     return url;
 }
 
@@ -173,11 +245,18 @@ void Dailymotion::setAccount(const QString &user, const QString &token, const QS
 }
 
 void Dailymotion::signIn(const QString &displayName, const QUrl &response) {
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(response);
+    QString code = query.queryItemValue("code");
+#else
     QString code = response.queryItemValue("code");
-
+#endif
     if (code.isEmpty()) {
+#if QT_VERSION >= 0x050000
+        QString errorString = query.queryItemValue("error");
+#else
         QString errorString = response.queryItemValue("error");
-
+#endif
         if (errorString == "access_denied") {
             emit info(tr("You have denied access to your Dailymotion account"));
         }
@@ -417,9 +496,17 @@ void Dailymotion::postFinished() {
 void Dailymotion::getPlaylists(int offset) {
     this->setPlaylistsLoaded(false);
     QUrl url(DAILYMOTION_PLAYLISTS_FEED);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("page", QString::number(offset));
+    query.addQueryItem("fields", DAILYMOTION_PLAYLIST_FIELDS);
+    query.addQueryItem("access_token", accessToken());
+    url.setQuery(query);
+#else
     url.addQueryItem("page", QString::number(offset));
     url.addQueryItem("fields", DAILYMOTION_PLAYLIST_FIELDS);
     url.addQueryItem("access_token", accessToken());
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -518,9 +605,17 @@ void Dailymotion::updatePlaylistVideoCount(const QString &id, int change) {
 void Dailymotion::getGroups(int offset) {
     this->setGroupsLoaded(false);
     QUrl url(DAILYMOTION_GROUPS_FEED);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("page", QString::number(offset));
+    query.addQueryItem("fields", DAILYMOTION_GROUP_FIELDS);
+    query.addQueryItem("access_token", accessToken());
+    url.setQuery(query);
+#else
     url.addQueryItem("page", QString::number(offset));
     url.addQueryItem("fields", DAILYMOTION_GROUP_FIELDS);
     url.addQueryItem("access_token", accessToken());
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -632,9 +727,17 @@ bool Dailymotion::memberOfGroup(const QString &groupId) {
 void Dailymotion::getSubscriptions(int offset) {
     this->setSubscriptionsLoaded(false);
     QUrl url(DAILYMOTION_SUBSCRIPTIONS_FEED);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("page", QString::number(offset));
+    query.addQueryItem("fields", DAILYMOTION_USER_FIELDS);
+    query.addQueryItem("access_token", accessToken());
+    url.setQuery(query);
+#else
     url.addQueryItem("page", QString::number(offset));
     url.addQueryItem("fields", DAILYMOTION_USER_FIELDS);
     url.addQueryItem("access_token", accessToken());
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -744,9 +847,15 @@ void Dailymotion::getFullVideo(QString id) {
     }
 
     QUrl url("https://api.dailymotion.com/video/" + id);
-
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("fields", DAILYMOTION_VIDEO_FIELDS);
+    query.addQueryItem("family_filter", "false");
+    url.setQuery(query);
+#else
     url.addQueryItem("fields", DAILYMOTION_VIDEO_FIELDS);
     url.addQueryItem("family_filter", "false");
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -779,7 +888,11 @@ void Dailymotion::checkFullVideo() {
             VideoItem *video = new VideoItem;
             video->loadDailymotionVideo(result);
 #ifdef QML_USER_INTERFACE
+#if QT_VERSION >= 0x050000
+            QQmlEngine::setObjectOwnership(video, QQmlEngine::JavaScriptOwnership);
+#else
             QDeclarativeEngine::setObjectOwnership(video, QDeclarativeEngine::JavaScriptOwnership);
+#endif
             emit gotVideo(video);
 #else
             emit gotVideo(QSharedPointer<VideoItem>(video));
@@ -808,8 +921,15 @@ void Dailymotion::checkFullVideo() {
 
 void Dailymotion::getVideoMetadata(const QString &id) {
     QUrl url("https://api.dailymotion.com/video/" + id);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("fields", DAILYMOTION_VIDEO_METADATA_FIELDS);
+    query.addQueryItem("access_token", this->accessToken());
+    url.setQuery(query);
+#else
     url.addQueryItem("fields", DAILYMOTION_VIDEO_METADATA_FIELDS);
     url.addQueryItem("access_token", this->accessToken());
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -863,8 +983,15 @@ void Dailymotion::checkVideoMetadata() {
 
 void Dailymotion::getCurrentUserProfile() {
     QUrl url("https://api.dailymotion.com/me");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("fields", DAILYMOTION_USER_PROFILE_FIELDS);
+    query.addQueryItem("access_token", accessToken());
+    url.setQuery(query);
+#else
     url.addQueryItem("fields", DAILYMOTION_USER_PROFILE_FIELDS);
     url.addQueryItem("access_token", accessToken());
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -900,7 +1027,11 @@ void Dailymotion::checkCurrentUserProfile() {
                 this->setUsername(user->id());
             }
 #ifdef QML_USER_INTERFACE
+#if QT_VERSION >= 0x050000
+            QQmlEngine::setObjectOwnership(user, QQmlEngine::JavaScriptOwnership);
+#else
             QDeclarativeEngine::setObjectOwnership(user, QDeclarativeEngine::JavaScriptOwnership);
+#endif
             emit gotUser(user);
 #else
             emit gotUser(QSharedPointer<UserItem>(user));
@@ -919,7 +1050,13 @@ void Dailymotion::checkCurrentUserProfile() {
 
 void Dailymotion::getUserProfile(const QString &id) {
     QUrl url("https://api.dailymotion.com/user/" + id);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("fields", DAILYMOTION_USER_PROFILE_FIELDS);
+    url.setQuery(query);
+#else
     url.addQueryItem("fields", DAILYMOTION_USER_PROFILE_FIELDS);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -955,7 +1092,11 @@ void Dailymotion::checkUserProfile() {
                 this->connect(this, SIGNAL(allSubscriptionsLoaded()), this, SLOT(subscribedToChannel()));
             }
 #ifdef QML_USER_INTERFACE
+#if QT_VERSION >= 0x050000
+            QQmlEngine::setObjectOwnership(user, QQmlEngine::JavaScriptOwnership);
+#else
             QDeclarativeEngine::setObjectOwnership(user, QDeclarativeEngine::JavaScriptOwnership);
+#endif
             emit gotUser(user);
 #else
             emit gotUser(QSharedPointer<UserItem>(user));
@@ -1280,7 +1421,13 @@ void Dailymotion::onPlaylistCreated(const QVariantMap &response) {
 
 void Dailymotion::getPlaylistForCache(const QString &id) {
     QUrl url("https://api.dailymotion.com/playlist/" + id);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("fields", DAILYMOTION_PLAYLIST_FIELDS);
+    url.setQuery(query);
+#else
     url.addQueryItem("fields", DAILYMOTION_PLAYLIST_FIELDS);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -1372,7 +1519,13 @@ void Dailymotion::onGroupJoined() {
 
 void Dailymotion::getGroupForCache(const QString &id) {
     QUrl url("https://api.dailymotion.com/group/" + id);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("fields", DAILYMOTION_GROUP_FIELDS);
+    url.setQuery(query);
+#else
     url.addQueryItem("fields", DAILYMOTION_GROUP_FIELDS);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -1468,7 +1621,13 @@ void Dailymotion::onCommentAdded(const QVariantMap &response) {
 
 void Dailymotion::getAddedComment(const QString &id) {
     QUrl url("https://api.dailymotion.com/comment/" + id);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("fields", DAILYMOTION_COMMENT_FIELDS);
+    url.setQuery(query);
+#else
     url.addQueryItem("fields", DAILYMOTION_COMMENT_FIELDS);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -1529,7 +1688,13 @@ void Dailymotion::onSubscribed() {
 
 void Dailymotion::getSubscriptionForCache(const QString &id) {
     QUrl url("https://api.dailymotion.com/user/" + id);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("fields", DAILYMOTION_USER_FIELDS);
+    url.setQuery(query);
+#else
     url.addQueryItem("fields", DAILYMOTION_USER_FIELDS);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -1643,11 +1808,19 @@ void Dailymotion::onCommentActionError(const QString &errorString) {
 void Dailymotion::getVideosFromIds(QStringList ids) {
     this->setBusy(true, QString(), 0);
     QUrl url(DAILYMOTION_VIDEOS_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("ids", ids.join(","));
+    query.addQueryItem("fields", DAILYMOTION_VIDEO_FIELDS);
+    query.addQueryItem("family_filter", safeSearch() ? "true" : "false");
+    query.addQueryItem("limit", "100");
+    url.setQuery(query);
+#else
     url.addQueryItem("ids", ids.join(","));
     url.addQueryItem("fields", DAILYMOTION_VIDEO_FIELDS);
     url.addQueryItem("family_filter", safeSearch() ? "true" : "false");
     url.addQueryItem("limit", "100");
-
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
