@@ -23,6 +23,9 @@ public:
 public:
     explicit DailymotionAccountsListModel(QObject *parent = 0);
     ~DailymotionAccountsListModel();
+#if QT_VERSION >= 0x050000
+    QHash<int, QByteArray> roleNames() const;
+#endif
     QVariant data(const QModelIndex &idx, int role) const;
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
 
@@ -40,6 +43,9 @@ signals:
     void accountDeleted();
     void error(const QString &errorString);
     void countChanged(int count);
+
+private:
+    QHash<int, QByteArray> m_roleNames;
 };
 
 #endif // DAILYMOTIONACCOUNTSLISTMODEL_H
