@@ -25,6 +25,9 @@ public:
 public:
     explicit DailymotionUserGroupListModel(QObject *parent = 0);
     ~DailymotionUserGroupListModel() {}
+#if QT_VERSION >= 0x050000
+    QHash<int, QByteArray> roleNames() const;
+#endif
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
@@ -39,6 +42,9 @@ private slots:
 
 signals:
     void countChanged(int count);
+
+private:
+    QHash<int, QByteArray> m_roleNames;
 };
 
 #endif // DAILYMOTIONUSERGROUPLISTMODEL_H
