@@ -36,7 +36,9 @@ class Videos : public QObject
 
 public:
     enum VideoFormat {
-        LQ = 0,
+        MobileLQ = 0,
+        MobileNormal,
+        LQ,
         Normal,
         HQ,
         HD,
@@ -93,7 +95,7 @@ class ScreenOrientation : public QObject
 
 public:
     enum Orientation {
-#ifdef Q_WS_SAILFISH
+#ifdef SAILFISH_OS
         LockPortrait = 1,
         LockLandscape = 2,
         LockPortraitInverted = 4,
