@@ -1,7 +1,7 @@
 #ifndef SCREENSAVER_H
 #define SCREENSAVER_H
 
-#ifndef Q_WS_SAILFISH
+#ifndef SAILFISH_OS
 #include <QObject>
 #include <qplatformdefs.h>
 #if defined (Q_WS_MAEMO_5)
