@@ -128,7 +128,7 @@ VideoServiceModel::VideoServiceModel(QObject *parent) :
 ScreenOrientationModel::ScreenOrientationModel(QObject *parent) :
     SelectionModel(parent)
 {
-#ifdef Q_WS_SAILFISH
+#ifdef SAILFISH_OS
     this->addItem(tr("Automatic"), ScreenOrientation::Automatic);
     this->addItem(tr("Portrait"), ScreenOrientation::LockPortrait);
     this->addItem(tr("Portrait (inverted)"), ScreenOrientation::LockPortraitInverted);
@@ -443,7 +443,7 @@ MediaPlayerModel::MediaPlayerModel(QObject *parent) :
 {
 #ifdef CUTETUBE_PLAYER_ENABLED
     this->addItem(tr("cuteTube Player"), "cutetube");
-#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SYMBIAN_OS)) || (defined (Q_WS_SAILFISH))
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SYMBIAN_OS)) || (defined (SAILFISH_OS))
     this->addItem(tr("cuteTube Player (simple)"), "cutetube_simple");
 #endif
 #endif
