@@ -12,6 +12,7 @@
 #include "transfermanager.h"
 #include "clipboardmonitor.h"
 #include "urlgrabber.h"
+#include "networkaccessmanager.h"
 #ifdef IN_APP_UPDATES
 #include "../updatemanager/updatemanager.h"
 #endif
@@ -21,13 +22,12 @@
 #include "../maemo5_gui/windowstack.h"
 #endif
 #endif
-#include <QNetworkAccessManager>
 
 Session* sessionInstance = 0;
 
 Session::Session(QObject *parent) :
     QObject(parent),
-    m_nam(new QNetworkAccessManager(this)),
+    m_nam(new NetworkAccessManager(this)),
     m_jar(new CookieJar(m_nam)),
     m_settings(new Settings(this)),
     m_database(new Database(this)),
