@@ -76,8 +76,8 @@ Settings* Settings::instance() {
 
 void Settings::restoreSettings() {
     this->beginGroup("Media");
-    this->setYouTubePlaybackFormats(this->value("youtubePlaybackFormats", QVariantList() << Videos::LQ).toList());
-    this->setYouTubeDownloadFormats(this->value("youtubeDownloadFormats", QVariantList() << Videos::LQ).toList());
+    this->setYouTubePlaybackFormats(this->value("youtubePlaybackFormats", QVariantList() << Videos::MobileLQ << Videos::MobileNormal << Videos::LQ).toList());
+    this->setYouTubeDownloadFormats(this->value("youtubeDownloadFormats", QVariantList() << Videos::MobileLQ << Videos::MobileNormal << Videos::LQ).toList());
     this->setDailymotionPlaybackFormats(this->value("dailymotionPlaybackFormats", QVariantList() << Videos::Normal).toList());
     this->setDailymotionDownloadFormats(this->value("dailymotionDownloadFormats", QVariantList() << Videos::Normal).toList());
 #ifdef Q_WS_MAEMO_5
@@ -261,13 +261,15 @@ void Settings::setYouTubePlaybackFormats(QVariantList formats) {
         m_youtubePlaybackFormats.insert(formats.takeFirst().toInt());
     }
 
-    m_youtubePlaybackFormats.insert(Videos::LQ);
+    m_youtubePlaybackFormats.insert(Videos::MobileLQ);
 
     emit youtubePlaybackFormatsChanged(m_youtubePlaybackFormats);
     emit enableYouTube1080PlaybackChanged();
     emit enableYouTube720PlaybackChanged();
     emit enableYouTube480PlaybackChanged();
     emit enableYouTube360PlaybackChanged();
+    emit enableYouTubeNormalPlaybackChanged();
+    emit enableYouTube240PlaybackChanged();
 }
 
 void Settings::setYouTubeDownloadFormats(QVariantList formats) {
@@ -275,13 +277,15 @@ void Settings::setYouTubeDownloadFormats(QVariantList formats) {
         m_youtubeDownloadFormats.insert(formats.takeFirst().toInt());
     }
 
-    m_youtubeDownloadFormats.insert(Videos::LQ);
+    m_youtubeDownloadFormats.insert(Videos::MobileLQ);
 
     emit youtubeDownloadFormatsChanged(m_youtubeDownloadFormats);
     emit enableYouTube1080DownloadChanged();
     emit enableYouTube720DownloadChanged();
     emit enableYouTube480DownloadChanged();
     emit enableYouTube360DownloadChanged();
+    emit enableYouTubeNormalDownloadChanged();
+    emit enableYouTube240DownloadChanged();
 }
 
 void Settings::setDailymotionPlaybackFormats(QVariantList formats) {
@@ -382,6 +386,30 @@ void Settings::setEnableYouTube360Playback(bool enable) {
     emit enableYouTube360PlaybackChanged();
 }
 
+void Settings::setEnableYouTubeNormalPlayback(bool enable) {
+    if (enable) {
+        m_youtubePlaybackFormats.insert(Videos::LQ);
+    }
+    else {
+        m_youtubePlaybackFormats.remove(Videos::LQ);
+    }
+
+    emit youtubePlaybackFormatsChanged(m_youtubePlaybackFormats);
+    emit enableYouTubeNormalPlaybackChanged();
+}
+
+void Settings::setEnableYouTube240Playback(bool enable) {
+    if (enable) {
+        m_youtubePlaybackFormats.insert(Videos::MobileNormal);
+    }
+    else {
+        m_youtubePlaybackFormats.remove(Videos::MobileNormal);
+    }
+
+    emit youtubePlaybackFormatsChanged(m_youtubePlaybackFormats);
+    emit enableYouTube240PlaybackChanged();
+}
+
 void Settings::setEnableYouTube1080Download(bool enable) {
     if (enable) {
         m_youtubeDownloadFormats.insert(Videos::SuperHD);
@@ -430,6 +458,30 @@ void Settings::setEnableYouTube360Download(bool enable) {
     emit enableYouTube360DownloadChanged();
 }
 
+void Settings::setEnableYouTubeNormalDownload(bool enable) {
+    if (enable) {
+        m_youtubeDownloadFormats.insert(Videos::LQ);
+    }
+    else {
+        m_youtubeDownloadFormats.remove(Videos::LQ);
+    }
+
+    emit youtubeDownloadFormatsChanged(m_youtubeDownloadFormats);
+    emit enableYouTubeNormalDownloadChanged();
+}
+
+void Settings::setEnableYouTube240Download(bool enable) {
+    if (enable) {
+        m_youtubeDownloadFormats.insert(Videos::MobileNormal);
+    }
+    else {
+        m_youtubeDownloadFormats.remove(Videos::MobileNormal);
+    }
+
+    emit youtubeDownloadFormatsChanged(m_youtubeDownloadFormats);
+    emit enableYouTube240DownloadChanged();
+}
+
 void Settings::setEnableDailymotion1080Playback(bool enable) {
     if (enable) {
         m_dailymotionPlaybackFormats.insert(Videos::SuperHD);
