@@ -30,6 +30,14 @@ class Settings : public QSettings
                READ enableYouTube360Playback
                WRITE setEnableYouTube360Playback
                NOTIFY enableYouTube360PlaybackChanged)
+    Q_PROPERTY(bool enableYouTubeNormalPlayback
+               READ enableYouTubeNormalPlayback
+               WRITE setEnableYouTubeNormalPlayback
+               NOTIFY enableYouTubeNormalPlaybackChanged)
+    Q_PROPERTY(bool enableYouTube240Playback
+               READ enableYouTube240Playback
+               WRITE setEnableYouTube240Playback
+               NOTIFY enableYouTube240PlaybackChanged)
     Q_PROPERTY(bool enableYouTube1080Download
                READ enableYouTube1080Download
                WRITE setEnableYouTube1080Download
@@ -46,6 +54,14 @@ class Settings : public QSettings
                READ enableYouTube360Download
                WRITE setEnableYouTube360Download
                NOTIFY enableYouTube360DownloadChanged)
+    Q_PROPERTY(bool enableYouTubeNormalDownload
+               READ enableYouTubeNormalDownload
+               WRITE setEnableYouTubeNormalDownload
+               NOTIFY enableYouTubeNormalDownloadChanged)
+    Q_PROPERTY(bool enableYouTube240Download
+               READ enableYouTube240Download
+               WRITE setEnableYouTube240Download
+               NOTIFY enableYouTube240DownloadChanged)
     Q_PROPERTY(bool enableDailymotion1080Playback
                READ enableDailymotion1080Playback
                WRITE setEnableDailymotion1080Playback
@@ -259,10 +275,14 @@ public:
     inline bool enableYouTube720Playback() const { return m_youtubePlaybackFormats.contains(Videos::HD); }
     inline bool enableYouTube480Playback() const { return m_youtubePlaybackFormats.contains(Videos::HQ); }
     inline bool enableYouTube360Playback() const { return m_youtubePlaybackFormats.contains(Videos::Normal); }
+    inline bool enableYouTubeNormalPlayback() const { return m_youtubePlaybackFormats.contains(Videos::LQ); }
+    inline bool enableYouTube240Playback() const { return m_youtubePlaybackFormats.contains(Videos::MobileNormal); }
     inline bool enableYouTube1080Download() const { return m_youtubeDownloadFormats.contains(Videos::SuperHD); }
     inline bool enableYouTube720Download() const { return m_youtubeDownloadFormats.contains(Videos::HD); }
     inline bool enableYouTube480Download() const { return m_youtubeDownloadFormats.contains(Videos::HQ); }
     inline bool enableYouTube360Download() const { return m_youtubeDownloadFormats.contains(Videos::Normal); }
+    inline bool enableYouTubeNormalDownload() const { return m_youtubeDownloadFormats.contains(Videos::LQ); }
+    inline bool enableYouTube240Download() const { return m_youtubeDownloadFormats.contains(Videos::MobileNormal); }
     inline bool enableDailymotion1080Playback() const { return m_dailymotionPlaybackFormats.contains(Videos::SuperHD); }
     inline bool enableDailymotion720Playback() const { return m_dailymotionPlaybackFormats.contains(Videos::HD); }
     inline bool enableDailymotion480Playback() const { return m_dailymotionPlaybackFormats.contains(Videos::HQ); }
@@ -329,10 +349,14 @@ public slots:
     void setEnableYouTube720Playback(bool enable);
     void setEnableYouTube480Playback(bool enable);
     void setEnableYouTube360Playback(bool enable);
+    void setEnableYouTubeNormalPlayback(bool enable);
+    void setEnableYouTube240Playback(bool enable);
     void setEnableYouTube1080Download(bool enable);
     void setEnableYouTube720Download(bool enable);
     void setEnableYouTube480Download(bool enable);
     void setEnableYouTube360Download(bool enable);
+    void setEnableYouTubeNormalDownload(bool enable);
+    void setEnableYouTube240Download(bool enable);
     void setEnableDailymotion1080Playback(bool enable);
     void setEnableDailymotion720Playback(bool enable);
     void setEnableDailymotion480Playback(bool enable);
@@ -408,10 +432,14 @@ signals:
     void enableYouTube720PlaybackChanged();
     void enableYouTube480PlaybackChanged();
     void enableYouTube360PlaybackChanged();
+    void enableYouTubeNormalPlaybackChanged();
+    void enableYouTube240PlaybackChanged();
     void enableYouTube1080DownloadChanged();
     void enableYouTube720DownloadChanged();
     void enableYouTube480DownloadChanged();
     void enableYouTube360DownloadChanged();
+    void enableYouTubeNormalDownloadChanged();
+    void enableYouTube240DownloadChanged();
     void enableDailymotion1080PlaybackChanged();
     void enableDailymotion720PlaybackChanged();
     void enableDailymotion480PlaybackChanged();
