@@ -176,7 +176,7 @@ void Sharing::checkTwitterAuthUrl() {
     else {
         this->setTwitterRequestToken(token);
         this->setTwitterRequestSecret(secret);
-        QUrl authUrl("http://api.twitter.com/oauth/authorize");
+        QUrl authUrl("https://api.twitter.com/oauth/authorize");
 #if QT_VERSION >= 0x050000
         QUrlQuery query;
         query.addQueryItem("oauth_token", token);
@@ -371,7 +371,7 @@ void Sharing::postToTwitter(const QVariantMap &post) {
 }
 
 void Sharing::postToTwitter() {
-    QUrl url("http://api.twitter.com/1.1/statuses/update.json");
+    QUrl url("https://api.twitter.com/1.1/statuses/update.json");
     QMap<QString, QString> params;
     params.insert("status", m_post.value("body").toString());
     QNetworkRequest request(url);
@@ -546,13 +546,12 @@ void Sharing::checkFacebookVideos() {
 
 void Sharing::getVideosFromTwitter() {
     this->setBusy(true);
-    QUrl url("http://api.twitter.com/1.1/statuses/home_timeline.json");
+    QUrl url("https://api.twitter.com/1.1/statuses/home_timeline.json");
 #if QT_VERSION >= 0x050000
     QUrlQuery query;
     query.addQueryItem("count", "200");
     query.addQueryItem("include_entities", "true");
     query.addQueryItem("trim_user", "true");
-    query.addQueryItem("include_rts", "false");
 
     if (!this->lastTweet().isEmpty()) {
         query.addQueryItem("since_id", this->lastTweet());
@@ -563,7 +562,6 @@ void Sharing::getVideosFromTwitter() {
     url.addQueryItem("count", "200");
     url.addQueryItem("include_entities", "true");
     url.addQueryItem("trim_user", "true");
-    url.addQueryItem("include_rts", "false");
 
     if (!this->lastTweet().isEmpty()) {
         url.addQueryItem("since_id", this->lastTweet());
