@@ -47,6 +47,14 @@ void UrlGrabber::setYouTubeFormats(QSet<int> formats) {
         videoFormat.format = static_cast<Videos::VideoFormat>(format);
 
         switch (format) {
+        case Videos::MobileLQ:
+            videoFormat.value = 17;
+            videoFormat.displayName = "144P AVC1";
+            break;
+        case Videos::MobileNormal:
+            videoFormat.value = 36;
+            videoFormat.displayName = "240P AVC1";
+            break;
         case Videos::LQ:
             videoFormat.value = 18;
             videoFormat.displayName = QString("%1 AVC1").arg(tr("Normal (upto 360P)"));
@@ -87,6 +95,9 @@ void UrlGrabber::setDailymotionFormats(QSet<int> formats) {
         videoFormat.format = static_cast<Videos::VideoFormat>(format);
 
         switch (format) {
+        case Videos::MobileLQ:
+        case Videos::MobileNormal:
+        case Videos::LQ:
         case Videos::Normal:
             videoFormat.value = "stream_h264_url";
             videoFormat.displayName = QString("%1 AVC1").arg(tr("Normal"));
@@ -123,15 +134,19 @@ void UrlGrabber::setVimeoFormats(QSet<int> formats) {
         videoFormat.format = static_cast<Videos::VideoFormat>(format);
 
         switch (format) {
+        case Videos::MobileLQ:
+        case Videos::MobileNormal:
         case Videos::LQ:
             videoFormat.value = "mobile";
             videoFormat.displayName = tr("Mobile");
             break;
         case Videos::Normal:
+        case Videos::HQ:
             videoFormat.value = "sd";
             videoFormat.displayName = "360P AVC1";
             break;
         case Videos::HD:
+        case Videos::SuperHD:
             videoFormat.value = "hd";
             videoFormat.displayName = "720P AVC1";
             break;
@@ -384,7 +399,7 @@ void UrlGrabber::checkYouTubeVideoInfoPage() {
         }
         else {
             qDebug() << "YouTube video info OK. Parsing the page";
-            response.replace(QRegExp("%2C(\\w+%3D1%26|)" + separator), "," + separator);
+            response = response.section('&', 0, 0).replace("%2C", ",");
             this->parseYouTubeVideoPage(QScriptValue(), response);
         }
     }
@@ -440,9 +455,9 @@ void UrlGrabber::checkYouTubeWebPage() {
         QVariantMap assets = Json::parse(QString("%1}").arg(response.section("\"assets\": ", 1, 1).section('}', 0, 0))).toMap();
         QUrl playerUrl = assets.value("js").toUrl();
 
-	if (playerUrl.scheme().isEmpty()) {
-	    playerUrl.setScheme("http");
-	}
+        if (playerUrl.scheme().isEmpty()) {
+            playerUrl.setScheme("http");
+        }
 
         response = response.section("url_encoded_fmt_stream_map\": \"", 1, 1).section(", \"", 0, 0).trimmed().replace("\\u0026", "&").remove(QRegExp("itag=\\d+"));
 
@@ -654,7 +669,7 @@ void UrlGrabber::checkYouTubeVideoInfoFormats() {
         }
         else {
             qDebug() << "YouTube video info OK. Parsing the page";
-            response.replace("%2C" + separator, "," + separator);
+            response = response.section('&', 0, 0).replace(QRegExp("%2C(\\w+%3D1%26|)" + separator), "," + separator);
             this->parseYouTubeVideoFormats(QScriptValue(), response);
         }
     }
@@ -687,9 +702,9 @@ void UrlGrabber::checkYouTubeWebPageFormats() {
         QVariantMap assets = Json::parse(QString("%1}").arg(response.section("\"assets\": ", 1, 1).section('}', 0, 0))).toMap();
         QUrl playerUrl = assets.value("js").toUrl();
 
-	if (playerUrl.scheme().isEmpty()) {
-	    playerUrl.setScheme("http");
-	}
+        if (playerUrl.scheme().isEmpty()) {
+            playerUrl.setScheme("http");
+        }
 
         response = response.section("url_encoded_fmt_stream_map\": \"", 1, 1).section(", \"", 0, 0).trimmed().replace("\\u0026", "&").remove(QRegExp("itag=\\d+"));
 
@@ -731,9 +746,9 @@ void UrlGrabber::parseYouTubeVideoFormats(QScriptValue decryptionFunction, QStri
     QVariantList formats;
     QList<int> keys;
 #ifdef SYMBIAN_OS
-    keys << 37 << 22 << 18;
+    keys << 37 << 22 << 18 << 36 << 17;
 #else
-    keys << 37 << 22 << 35 << 34 << 18;
+    keys << 37 << 22 << 35 << 34 << 18 << 36 << 17;
 #endif
     QMap<int, QUrl> urlMap = this->getYouTubeVideoUrlMap(page, decryptionFunction);
 
@@ -754,7 +769,7 @@ void UrlGrabber::parseYouTubeVideoFormats(QScriptValue decryptionFunction, QStri
                 format["service"] = Services::YouTube;
                 formats << format;
                 break;
-    #ifndef SYMBIAN_OS
+#ifndef SYMBIAN_OS
             case 35:
                 format["name"] = "480P FLV";
                 format["service"] = Services::YouTube;
@@ -765,11 +780,22 @@ void UrlGrabber::parseYouTubeVideoFormats(QScriptValue decryptionFunction, QStri
                 format["service"] = Services::YouTube;
                 formats << format;
                 break;
-    #endif
+#endif
             case 18:
                 format["name"] = QString("%1 AVC1").arg(tr("Normal"));
                 format["service"] = Services::YouTube;
                 formats << format;
+                break;
+            case 36:
+                format["name"] = "240P AVC1";
+                format["service"] = Services::YouTube;
+                formats << format;
+                break;
+            case 17:
+                format["name"] = "144P AVC1";
+                format["service"] = Services::YouTube;
+                formats << format;
+                break;
             default:
                 break;
             }
