@@ -46,7 +46,6 @@ public slots:
     void getAvailableYouTubeVideoFormats(const QString &id);
     void getAvailableDailymotionVideoFormats(const QString &id);
     void getAvailableVimeoVideoFormats(const QString &id);
-    void getVimeoVideoRedirect(const QUrl &url);
     void setYouTubeFormats(QSet<int> formats);
     void setDailymotionFormats(QSet<int> formats);
     void setVimeoFormats(QSet<int> formats);
@@ -66,7 +65,6 @@ private slots:
     void parseYouTubeVideoPage(QScriptValue decryptionFunction = QScriptValue(), QString page = QString());
     void parseDailymotionVideoPage();
     void parseVimeoVideoPage();
-    void checkVimeoVideoRedirect();
     void checkYouTubeVideoInfoFormats();
     void checkYouTubeWebPageFormats();
     void parseYouTubeVideoFormats(QScriptValue decryptionFunction = QScriptValue(), QString page = QString());
