@@ -5,6 +5,12 @@
 #include <QString>
 #include <QDateTime>
 
+#ifndef QML_USER_INTERFACE
+class QPainter;
+class QRect;
+class QImage;
+#endif
+
 class Utils
 {
 
@@ -21,6 +27,9 @@ public:
     static QString unescape(const QString &s);
     static void log(const QString &filePath, const QByteArray &message);
     static QString versionNumberString();
+#ifndef QML_USER_INTERFACE
+    static void drawBorderImage(QPainter *painter, const QRect &rect, const QImage &image, int top, int right, int left, int bottom);
+#endif
 };
 
 #endif // UTILS_H
