@@ -9,8 +9,15 @@
 #include <QStringList>
 #include <QDebug>
 #ifdef QML_USER_INTERFACE
+#if QT_VERSION >= 0x050000
+#include <QQmlEngine>
+#else
 #include <QDeclarativeEngine>
 #endif
+#endif
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 using namespace QtOAuth;
 
@@ -55,17 +62,16 @@ Vimeo* Vimeo::instance() {
 void Vimeo::setBusy(bool isBusy, const QString &message, int numberOfOperations) {
     if (isBusy != this->busy()) {
         m_busy = isBusy;
-
-        if (isBusy) {
-            this->setCancelled(false);
-            emit busy(message, numberOfOperations);
-        }
-        else if (!this->cancelled()) {
-            emit busyProgressChanged(numberOfOperations);
-        }
-
         emit busyChanged(isBusy);
     }
+
+    if (isBusy) {
+        this->setCancelled(false);
+        emit busy(message, numberOfOperations);
+    }
+    else if (!this->cancelled()) {
+        emit busyProgressChanged(numberOfOperations);
+    }
 }
 
 void Vimeo::cancelCurrentOperation() {
@@ -82,10 +88,19 @@ void Vimeo::cancelCurrentOperation() {
 }
 
 QNetworkReply* Vimeo::createReply(QUrl feed, int offset) {
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(feed);
+
+    if (offset) {
+        query.addQueryItem("page", QString::number(offset));
+    }
+
+    feed.setQuery(query);
+#else
     if (offset) {
         feed.addQueryItem("page", QString::number(offset));
     }
-
+#endif
     qDebug() << feed;
 
     QNetworkRequest request(feed);
@@ -97,6 +112,20 @@ QNetworkReply* Vimeo::createReply(QUrl feed, int offset) {
 
 QNetworkReply* Vimeo::createSearchReply(const QString &query, int offset, int order) {
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery urlQuery(url);
+    urlQuery.addQueryItem("method", "vimeo.videos.search");
+    urlQuery.addQueryItem("sort", m_queryOrders.value(order, "relevant"));
+    urlQuery.addQueryItem("query", query.simplified());
+    urlQuery.addQueryItem("per_page", "30");
+    urlQuery.addQueryItem("full_response", "true");
+
+    if (offset) {
+        urlQuery.addQueryItem("page", QString::number(offset));
+    }
+
+    url.setQuery(urlQuery);
+#else
     url.addQueryItem("method", "vimeo.videos.search");
     url.addQueryItem("sort", m_queryOrders.value(order, "relevant"));
     url.addQueryItem("query", query.simplified());
@@ -106,7 +135,7 @@ QNetworkReply* Vimeo::createSearchReply(const QString &query, int offset, int or
     if (offset) {
         url.addQueryItem("page", QString::number(offset));
     }
-
+#endif
     qDebug() << url;
 
     QNetworkRequest request(url);
@@ -148,9 +177,14 @@ void Vimeo::checkAuthUrl() {
     }
 
     QUrl url("http://vimeo.com?" + reply->readAll());
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    QString token = query.queryItemValue("oauth_token");
+    QString secret = query.queryItemValue("oauth_token_secret");
+#else
     QString token = url.queryItemValue("oauth_token");
     QString secret = url.queryItemValue("oauth_token_secret");
-
+#endif
     if ((token.isEmpty()) || (secret.isEmpty())) {
         emit error(tr("Error obtaining Vimeo authorisation URL"));
     }
@@ -158,8 +192,15 @@ void Vimeo::checkAuthUrl() {
         this->setRequestToken(token);
         this->setRequestSecret(secret);
         QUrl authUrl("https://vimeo.com/oauth/authorize");
+#if QT_VERSION >= 0x050000
+        QUrlQuery query;
+        query.addQueryItem("oauth_token", token);
+        query.addQueryItem("permission", "delete");
+        authUrl.setQuery(query);
+#else
         authUrl.addQueryItem("oauth_token", token);
         authUrl.addQueryItem("permission", "delete");
+#endif
         emit gotAuthUrl(authUrl);
     }
 
@@ -167,8 +208,12 @@ void Vimeo::checkAuthUrl() {
 }
 
 void Vimeo::signIn(const QString &displayName, const QUrl &response) {
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(response);
+    QString verifier = query.queryItemValue("oauth_verifier");
+#else
     QString verifier = response.queryItemValue("oauth_verifier");
-
+#endif
     if (verifier.isEmpty()) {
         emit error(tr("Error obtaining Vimeo authorisation verifier"));
     }
@@ -199,9 +244,14 @@ void Vimeo::checkIfSignedIn() {
     }
 
     QUrl url("http://vimeo.com?" + reply->readAll());
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    QString token = query.queryItemValue("oauth_token");
+    QString secret = query.queryItemValue("oauth_token_secret");
+#else
     QString token = url.queryItemValue("oauth_token");
     QString secret = url.queryItemValue("oauth_token_secret");
-
+#endif
     if ((token.isEmpty()) || (secret.isEmpty())) {
         emit error(tr("Error obtaining Vimeo authorisation"));
     }
@@ -283,7 +333,13 @@ void Vimeo::postFinished() {
 void Vimeo::getAlbums(int offset) {
     this->setAlbumsLoaded(false);
     QUrl url(VIMEO_ALBUMS_FEED);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("page", QString::number(offset));
+    url.setQuery(query);
+#else
     url.addQueryItem("page", QString::number(offset));
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
@@ -395,8 +451,15 @@ void Vimeo::updateAlbumThumbnail(const QString &id, const QUrl &thumbnailUrl) {
 void Vimeo::getGroups(int offset) {
     this->setGroupsLoaded(false);
     QUrl url(VIMEO_GROUPS_FEED);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("user_id", this->username());
+    query.addQueryItem("page", QString::number(offset));
+    url.setQuery(query);
+#else
     url.addQueryItem("user_id", this->username());
     url.addQueryItem("page", QString::number(offset));
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
@@ -480,7 +543,13 @@ QSharedPointer<GroupItem> Vimeo::removeGroupFromCache(const QString &id) {
 void Vimeo::getSubscriptions(int offset) {
     this->setSubscriptionsLoaded(false);
     QUrl url(VIMEO_SUBSCRIPTIONS_FEED);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("page", QString::number(offset));
+    url.setQuery(query);
+#else
     url.addQueryItem("page", QString::number(offset));
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
@@ -566,8 +635,15 @@ void Vimeo::getFullVideo(QString id) {
     this->setBusy(true, tr("Retrieving video details"));
     id = id.section('/', -1);
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "vimeo.videos.getInfo");
+    query.addQueryItem("video_id", id);
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "vimeo.videos.getInfo");
     url.addQueryItem("video_id", id);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
@@ -599,7 +675,11 @@ void Vimeo::checkFullVideo() {
         VideoItem *video = new VideoItem;
         video->loadVimeoVideo(responseNode.firstChildElement("video"));
 #ifdef QML_USER_INTERFACE
-        QDeclarativeEngine::setObjectOwnership(video, QDeclarativeEngine::JavaScriptOwnership);
+#if QT_VERSION >= 0x050000
+            QQmlEngine::setObjectOwnership(video, QQmlEngine::JavaScriptOwnership);
+#else
+            QDeclarativeEngine::setObjectOwnership(video, QDeclarativeEngine::JavaScriptOwnership);
+#endif
         emit gotVideo(video);
 #else
         emit gotVideo(QSharedPointer<VideoItem>(video));
@@ -626,7 +706,13 @@ void Vimeo::checkFullVideo() {
 
 void Vimeo::getCurrentUserProfile() {
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "people.getInfo");
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "people.getInfo");
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
@@ -655,7 +741,11 @@ void Vimeo::checkCurrentUserProfile() {
         }
 
 #ifdef QML_USER_INTERFACE
-        QDeclarativeEngine::setObjectOwnership(user, QDeclarativeEngine::JavaScriptOwnership);
+#if QT_VERSION >= 0x050000
+            QQmlEngine::setObjectOwnership(user, QQmlEngine::JavaScriptOwnership);
+#else
+            QDeclarativeEngine::setObjectOwnership(user, QDeclarativeEngine::JavaScriptOwnership);
+#endif
         emit gotUser(user);
 #else
         emit gotUser(QSharedPointer<UserItem>(user));
@@ -677,8 +767,15 @@ void Vimeo::checkCurrentUserProfile() {
 
 void Vimeo::getUserProfile(const QString &id) {
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "people.getInfo");
+    query.addQueryItem("user_id", id);
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "people.getInfo");
     url.addQueryItem("user_id", id);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
@@ -702,7 +799,11 @@ void Vimeo::checkUserProfile() {
         UserItem *user = new UserItem;
         user->loadVimeoProfile(responseNode.firstChildElement("person"));
 #ifdef QML_USER_INTERFACE
-        QDeclarativeEngine::setObjectOwnership(user, QDeclarativeEngine::JavaScriptOwnership);
+#if QT_VERSION >= 0x050000
+            QQmlEngine::setObjectOwnership(user, QQmlEngine::JavaScriptOwnership);
+#else
+            QDeclarativeEngine::setObjectOwnership(user, QDeclarativeEngine::JavaScriptOwnership);
+#endif
         emit gotUser(user);
 #else
         emit gotUser(QSharedPointer<UserItem>(user));
@@ -737,8 +838,15 @@ void Vimeo::deleteFromUploads(const QStringList &videoIds) {
 void Vimeo::deleteFromUploads() {
     if (!m_actionIdList.isEmpty()) {
         QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+        QUrlQuery query(url);
+        query.addQueryItem("method", "vimeo.videos.delete");
+        query.addQueryItem("video_id", m_actionIdList.first());
+        url.setQuery(query);
+#else
         url.addQueryItem("method", "vimeo.videos.delete");
         url.addQueryItem("video_id", m_actionIdList.first());
+#endif
         this->postRequest(url);
         this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onVideoDeleted()));
         this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
@@ -781,9 +889,17 @@ void Vimeo::addToLikes(const QStringList &videoIds) {
 void Vimeo::addToLikes() {
     if (!m_actionIdList.isEmpty()) {
         QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+        QUrlQuery query(url);
+        query.addQueryItem("method", "vimeo.videos.setLike");
+        query.addQueryItem("video_id", m_actionIdList.first());
+        query.addQueryItem("like", "true");
+        url.setQuery(query);
+#else
         url.addQueryItem("method", "vimeo.videos.setLike");
         url.addQueryItem("video_id", m_actionIdList.first());
         url.addQueryItem("like", "true");
+#endif
         this->postRequest(url);
         this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onAddedToLikes(QString)));
         this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
@@ -828,9 +944,17 @@ void Vimeo::deleteFromLikes(const QStringList &videoIds) {
 void Vimeo::deleteFromLikes() {
     if (!m_actionIdList.isEmpty()) {
         QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+        QUrlQuery query(url);
+        query.addQueryItem("method", "vimeo.videos.setLike");
+        query.addQueryItem("video_id", m_actionIdList.first());
+        query.addQueryItem("like", "false");
+        url.setQuery(query);
+#else
         url.addQueryItem("method", "vimeo.videos.setLike");
         url.addQueryItem("video_id", m_actionIdList.first());
         url.addQueryItem("like", "false");
+#endif
         this->postRequest(url);
         this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onDeletedFromLikes()));
         this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
@@ -874,9 +998,17 @@ void Vimeo::addToAlbum(const QStringList &videoIds, const QString &albumId) {
 void Vimeo::addToAlbum() {
     if (!m_actionIdList.isEmpty()) {
         QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+        QUrlQuery query(url);
+        query.addQueryItem("method", "vimeo.albums.addVideo");
+        query.addQueryItem("album_id", m_actionId);
+        query.addQueryItem("video_id", m_actionIdList.first());
+        url.setQuery(query);
+#else
         url.addQueryItem("method", "vimeo.albums.addVideo");
         url.addQueryItem("album_id", m_actionId);
         url.addQueryItem("video_id", m_actionIdList.first());
+#endif
         this->postRequest(url);
         this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onAddedToAlbum(QString)));
         this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
@@ -926,9 +1058,17 @@ void Vimeo::deleteFromAlbum(const QStringList &videoIds, const QString &albumId)
 void Vimeo::deleteFromAlbum() {
     if (!m_actionIdList.isEmpty()) {
         QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+        QUrlQuery query(url);
+        query.addQueryItem("method", "vimeo.albums.removeVideo");
+        query.addQueryItem("album_id", m_actionId);
+        query.addQueryItem("video_id", m_actionIdList.first());
+        url.setQuery(query);
+#else
         url.addQueryItem("method", "vimeo.albums.removeVideo");
         url.addQueryItem("album_id", m_actionId);
         url.addQueryItem("video_id", m_actionIdList.first());
+#endif
         this->postRequest(url);
         this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onDeletedFromAlbum()));
         this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
@@ -974,8 +1114,15 @@ void Vimeo::addToWatchLaterAlbum(const QStringList &videoIds) {
 void Vimeo::addToWatchLaterAlbum() {
     if (!m_actionIdList.isEmpty()) {
         QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+        QUrlQuery query(url);
+        query.addQueryItem("method", "vimeo.albums.addToWatchLater");
+        query.addQueryItem("video_id", m_actionIdList.first());
+        url.setQuery(query);
+#else
         url.addQueryItem("method", "vimeo.albums.addToWatchLater");
         url.addQueryItem("video_id", m_actionIdList.first());
+#endif
         this->postRequest(url);
         this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onAddedToWatchLaterAlbum(QString)));
         this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
@@ -1020,8 +1167,15 @@ void Vimeo::deleteFromWatchLaterAlbum(const QStringList &videoIds) {
 void Vimeo::deleteFromWatchLaterAlbum() {
     if (!m_actionIdList.isEmpty()) {
         QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+        QUrlQuery query(url);
+        query.addQueryItem("method", "vimeo.albums.removeFromWatchLater");
+        query.addQueryItem("video_id", m_actionIdList.first());
+        url.setQuery(query);
+#else
         url.addQueryItem("method", "vimeo.albums.removeFromWatchLater");
         url.addQueryItem("video_id", m_actionIdList.first());
+#endif
         this->postRequest(url);
         this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onDeletedFromWatchLaterAlbum()));
         this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onVideoActionError(QString)));
@@ -1063,10 +1217,19 @@ void Vimeo::createAlbum(const QVariantMap &album, const QStringList &videoIds) {
 void Vimeo::createAlbum() {
     if (!m_actionIdList.isEmpty()) {
         QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+        QUrlQuery query(url);
+        query.addQueryItem("method", "vimeo.albums.create");
+        query.addQueryItem("title", m_metadataAction.value("title").toString());
+        query.addQueryItem("description", m_metadataAction.value("description").toString());
+        query.addQueryItem("video_id", m_actionIdList.takeFirst());
+        url.setQuery(query);
+#else
         url.addQueryItem("method", "vimeo.albums.create");
         url.addQueryItem("title", m_metadataAction.value("title").toString());
         url.addQueryItem("description", m_metadataAction.value("description").toString());
         url.addQueryItem("video_id", m_actionIdList.takeFirst());
+#endif
         this->postRequest(url);
         this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onAlbumCreated(QString)));
         this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onAlbumActionError(QString)));
@@ -1101,9 +1264,17 @@ void Vimeo::onAlbumCreated(const QString &response) {
 
 void Vimeo::getAlbumForCache() {
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "vimeo.albums.getAll");
+    query.addQueryItem("sort", "newest");
+    query.addQueryItem("per_page", "1");
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "vimeo.albums.getAll");
     url.addQueryItem("sort", "newest");
     url.addQueryItem("per_page", "1");
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
@@ -1151,8 +1322,15 @@ void Vimeo::deleteAlbum(const QString &albumId) {
 
 void Vimeo::deleteAlbum() {
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "vimeo.albums.delete");
+    query.addQueryItem("album_id", m_actionId);
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "vimeo.albums.delete");
     url.addQueryItem("album_id", m_actionId);
+#endif
     this->postRequest(url);
     this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onAlbumDeleted()));
     this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onAlbumActionError(QString)));
@@ -1176,8 +1354,15 @@ void Vimeo::joinGroup(const QString &groupId) {
 
 void Vimeo::joinGroup() {
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "vimeo.groups.join");
+    query.addQueryItem("group_id", m_actionId);
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "vimeo.groups.join");
     url.addQueryItem("group_id", m_actionId);
+#endif
     this->postRequest(url);
     this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onGroupJoined()));
     this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onGroupActionError(QString)));
@@ -1195,8 +1380,15 @@ void Vimeo::onGroupJoined() {
 
 void Vimeo::getGroupForCache(const QString &id) {
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "vimeo.groups.getInfo");
+    query.addQueryItem("group_id", id);
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "vimeo.groups.getInfo");
     url.addQueryItem("group_id", id);
+#endif
     QNetworkRequest request(url);
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkCacheGroup()));
@@ -1240,8 +1432,15 @@ void Vimeo::leaveGroup(const QString &groupId) {
 
 void Vimeo::leaveGroup() {
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "vimeo.groups.leave");
+    query.addQueryItem("group_id", m_actionId);
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "vimeo.groups.leave");
     url.addQueryItem("group_id", m_actionId);
+#endif
     this->postRequest(url);
     this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onGroupLeft()));
     this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onGroupActionError(QString)));
@@ -1266,8 +1465,15 @@ void Vimeo::subscribe(const QString &userId) {
 
 void Vimeo::subscribe() {
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "vimeo.people.addContact");
+    query.addQueryItem("user_id", m_actionId);
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "vimeo.people.addContact");
     url.addQueryItem("user_id", m_actionId);
+#endif
     this->postRequest(url);
     this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onSubscribed(QString)));
     this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onUserActionError(QString)));
@@ -1290,8 +1496,15 @@ void Vimeo::onSubscribed(const QString &response) {
 
 void Vimeo::getSubscriptionForCache(const QString &id) {
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "vimeo.people.getInfo");
+    query.addQueryItem("user_id", id);
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "vimeo.people.getInfo");
     url.addQueryItem("user_id", id);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
@@ -1338,8 +1551,15 @@ void Vimeo::unsubscribe(const QString &userId) {
 
 void Vimeo::unsubscribe() {
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "vimeo.people.removeContact");
+    query.addQueryItem("user_id", m_actionId);
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "vimeo.people.removeContact");
     url.addQueryItem("user_id", m_actionId);
+#endif
     this->postRequest(url);
     this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onUnsubscribed()));
     this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onUserActionError(QString)));
@@ -1373,9 +1593,17 @@ void Vimeo::addComment(const QVariantMap &comment) {
 
 void Vimeo::addComment() {
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "vimeo.videos.comments.addComment");
+    query.addQueryItem("video_id", m_metadataAction.value("videoId").toString());
+    query.addQueryItem("comment_text", m_metadataAction.value("body").toString());
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "vimeo.videos.comments.addComment");
     url.addQueryItem("video_id", m_metadataAction.value("videoId").toString());
     url.addQueryItem("comment_text", m_metadataAction.value("body").toString());
+#endif
     this->postRequest(url);
     this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onCommentAdded(QString)));
     this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onCommentActionError(QString)));
@@ -1388,10 +1616,19 @@ void Vimeo::replyToComment(const QVariantMap &comment) {
 
 void Vimeo::replyToComment() {
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "vimeo.videos.comments.addComment");
+    query.addQueryItem("video_id", m_metadataAction.value("videoId").toString());
+    query.addQueryItem("reply_to_comment_id", m_metadataAction.value("replyId").toString());
+    query.addQueryItem("comment_text", m_metadataAction.value("body").toString());
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "vimeo.videos.comments.addComment");
     url.addQueryItem("video_id", m_metadataAction.value("videoId").toString());
     url.addQueryItem("reply_to_comment_id", m_metadataAction.value("replyId").toString());
     url.addQueryItem("comment_text", m_metadataAction.value("body").toString());
+#endif
     this->postRequest(url);
     this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onCommentAdded(QString)));
     this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onCommentActionError(QString)));
@@ -1408,9 +1645,17 @@ void Vimeo::onCommentAdded(const QString &response) {
 void Vimeo::getAddedComment(const QString &videoId) {
     m_actionId = videoId;
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "vimeo.video.comments.getList");
+    query.addQueryItem("video_id", m_actionId);
+    query.addQueryItem("per_page", "1");
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "vimeo.video.comments.getList");
     url.addQueryItem("video_id", m_actionId);
     url.addQueryItem("per_page", "1");
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
@@ -1497,8 +1742,15 @@ void Vimeo::getVideosFromIds(QStringList ids) {
 
 void Vimeo::getVideoFromId(const QString &id) {
     QUrl url(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("method", "vimeo.videos.getInfo");
+    query.addQueryItem("video_id", id);
+    url.setQuery(query);
+#else
     url.addQueryItem("method", "vimeo.videos.getInfo");
     url.addQueryItem("video_id", id);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
