@@ -4,6 +4,9 @@
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QTimer>
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 VimeoCommentListModel::VimeoCommentListModel(QObject *parent) :
     AbstractCommentListModel(parent),
@@ -35,9 +38,17 @@ void VimeoCommentListModel::setVideoId(const QString &id) {
     if (id != this->videoId()) {
         m_videoId = id;
         QUrl feed(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+        QUrlQuery query(feed);
+        query.addQueryItem("method", "vimeo.videos.comments.getList");
+        query.addQueryItem("video_id", id);
+        query.addQueryItem("per_page", "30");
+        feed.setQuery(query);
+#else
         feed.addQueryItem("method", "vimeo.videos.comments.getList");
         feed.addQueryItem("video_id", id);
         feed.addQueryItem("per_page", "30");
+#endif
         this->setFeed(feed);
     }
 }
