@@ -16,11 +16,7 @@ public:
 
 signals:
     void showUserChannel(const QModelIndex &index);
-    void getInitialComment(int row);
-    
-private:
-    bool m_avatarPressed;
-    bool m_arrowPressed;
+//    void getInitialComment(int row);
 };
 
 #endif // COMMENTDELEGATE_H
