@@ -13,6 +13,8 @@ DownloadFormatDialog::DownloadFormatDialog(QWidget *parent) :
     m_youtube480Checkbox(new QCheckBox("480P FLV", this)),
     m_youtube360Checkbox(new QCheckBox("360P FLV", this)),
     m_youtubeNormalCheckbox(new QCheckBox(tr("Normal") + " AVC1", this)),
+    m_youtube240Checkbox(new QCheckBox("240P AVC1", this)),
+    m_youtube144Checkbox(new QCheckBox("144P AVC1", this)),
     m_dailymotion720Checkbox(new QCheckBox("720P AVC1", this)),
     m_dailymotion480Checkbox(new QCheckBox("480P AVC1", this)),
     m_dailymotionNormalCheckbox(new QCheckBox(tr("Normal") + " AVC1", this)),
@@ -35,6 +37,8 @@ DownloadFormatDialog::DownloadFormatDialog(QWidget *parent) :
     vbox->addWidget(m_youtube480Checkbox);
     vbox->addWidget(m_youtube360Checkbox);
     vbox->addWidget(m_youtubeNormalCheckbox);
+    vbox->addWidget(m_youtube240Checkbox);
+    vbox->addWidget(m_youtube144Checkbox);
     vbox->addWidget(new SeparatorLabel("Dailymotion", this));
     vbox->addWidget(m_dailymotion720Checkbox);
     vbox->addWidget(m_dailymotion480Checkbox);
@@ -87,8 +91,10 @@ void DownloadFormatDialog::loadSettings() {
     m_youtube720Checkbox->setChecked(Settings::instance()->enableYouTube720Download());
     m_youtube480Checkbox->setChecked(Settings::instance()->enableYouTube480Download());
     m_youtube360Checkbox->setChecked(Settings::instance()->enableYouTube360Download());
-    m_youtubeNormalCheckbox->setChecked(true);
-    m_youtubeNormalCheckbox->setEnabled(false);
+    m_youtubeNormalCheckbox->setChecked(Settings::instance()->enableYouTubeNormalDownload());
+    m_youtube240Checkbox->setChecked(Settings::instance()->enableYouTube240Download());
+    m_youtube144Checkbox->setChecked(true);
+    m_youtube144Checkbox->setEnabled(false);
     m_dailymotion720Checkbox->setChecked(Settings::instance()->enableDailymotion720Download());
     m_dailymotion480Checkbox->setChecked(Settings::instance()->enableDailymotion480Download());
     m_dailymotionNormalCheckbox->setChecked(true);
@@ -104,6 +110,8 @@ void DownloadFormatDialog::saveSettings() {
     Settings::instance()->setEnableYouTube720Download(m_youtube720Checkbox->isChecked());
     Settings::instance()->setEnableYouTube480Download(m_youtube480Checkbox->isChecked());
     Settings::instance()->setEnableYouTube360Download(m_youtube360Checkbox->isChecked());
+    Settings::instance()->setEnableYouTubeNormalDownload(m_youtubeNormalCheckbox->isChecked());
+    Settings::instance()->setEnableYouTube240Download(m_youtube240Checkbox->isChecked());
     Settings::instance()->setEnableDailymotion720Download(m_dailymotion720Checkbox->isChecked());
     Settings::instance()->setEnableDailymotion480Download(m_dailymotion480Checkbox->isChecked());
     Settings::instance()->setEnableVimeo720Download(m_vimeo720Checkbox->isChecked());
