@@ -3,7 +3,6 @@
 
 #include "abstractdialog.h"
 
-class Session;
 class QLineEdit;
 class QPushButton;
 class QDialogButtonBox;
@@ -43,7 +42,7 @@ class LinkGoogleAccountDialog : public AbstractDialog
     Q_OBJECT
 
 public:
-    explicit LinkGoogleAccountDialog(Session *session, QWidget *parent = 0);
+    explicit LinkGoogleAccountDialog(QWidget *parent = 0);
     
 private:
     void setLandscapeLayout();
@@ -57,7 +56,6 @@ private slots:
     void onUsernameUnavailable();
 
 private:
-    Session *m_session;
     QLineEdit *m_usernameEdit;
     QLabel *m_messageLabel;
     QDialogButtonBox *m_buttonBox;
