@@ -12,6 +12,8 @@ PlaybackFormatDialog::PlaybackFormatDialog(QWidget *parent) :
     m_youtube480Checkbox(new QCheckBox("480P FLV", this)),
     m_youtube360Checkbox(new QCheckBox("360P FLV", this)),
     m_youtubeNormalCheckbox(new QCheckBox(tr("Normal") + " AVC1", this)),
+    m_youtube240Checkbox(new QCheckBox("240P AVC1", this)),
+    m_youtube144Checkbox(new QCheckBox("144P AVC1", this)),
     m_dailymotion720Checkbox(new QCheckBox("720P AVC1", this)),
     m_dailymotion480Checkbox(new QCheckBox("480P AVC1", this)),
     m_dailymotionNormalCheckbox(new QCheckBox(tr("Normal") + " AVC1", this)),
@@ -33,6 +35,8 @@ PlaybackFormatDialog::PlaybackFormatDialog(QWidget *parent) :
     vbox->addWidget(m_youtube480Checkbox);
     vbox->addWidget(m_youtube360Checkbox);
     vbox->addWidget(m_youtubeNormalCheckbox);
+    vbox->addWidget(m_youtube240Checkbox);
+    vbox->addWidget(m_youtube144Checkbox);
     vbox->addWidget(new SeparatorLabel("Dailymotion", this));
     vbox->addWidget(m_dailymotion720Checkbox);
     vbox->addWidget(m_dailymotion480Checkbox);
@@ -84,8 +88,10 @@ void PlaybackFormatDialog::loadSettings() {
     m_youtube720Checkbox->setChecked(Settings::instance()->enableYouTube720Playback());
     m_youtube480Checkbox->setChecked(Settings::instance()->enableYouTube480Playback());
     m_youtube360Checkbox->setChecked(Settings::instance()->enableYouTube360Playback());
-    m_youtubeNormalCheckbox->setChecked(true);
-    m_youtubeNormalCheckbox->setEnabled(false);
+    m_youtubeNormalCheckbox->setChecked(Settings::instance()->enableYouTubeNormalPlayback());
+    m_youtube240Checkbox->setChecked(Settings::instance()->enableYouTube240Playback());
+    m_youtube144Checkbox->setChecked(true);
+    m_youtube144Checkbox->setEnabled(false);
     m_dailymotion720Checkbox->setChecked(Settings::instance()->enableDailymotion720Playback());
     m_dailymotion480Checkbox->setChecked(Settings::instance()->enableDailymotion480Playback());
     m_dailymotionNormalCheckbox->setChecked(true);
@@ -100,6 +106,8 @@ void PlaybackFormatDialog::saveSettings() {
     Settings::instance()->setEnableYouTube720Playback(m_youtube720Checkbox->isChecked());
     Settings::instance()->setEnableYouTube480Playback(m_youtube480Checkbox->isChecked());
     Settings::instance()->setEnableYouTube360Playback(m_youtube360Checkbox->isChecked());
+    Settings::instance()->setEnableYouTubeNormalPlayback(m_youtubeNormalCheckbox->isChecked());
+    Settings::instance()->setEnableYouTube240Playback(m_youtube240Checkbox->isChecked());
     Settings::instance()->setEnableDailymotion720Playback(m_dailymotion720Checkbox->isChecked());
     Settings::instance()->setEnableDailymotion480Playback(m_dailymotion480Checkbox->isChecked());
     Settings::instance()->setEnableVimeo720Playback(m_vimeo720Checkbox->isChecked());
