@@ -4,7 +4,6 @@
 #include "abstractdialog.h"
 #include "../base/videoitem.h"
 
-class Session;
 class QLineEdit;
 class QTextEdit;
 class QPushButton;
@@ -15,8 +14,9 @@ class QGridLayout;
 class ShareToFacebookDialog : public AbstractDialog
 {
     Q_OBJECT
+
 public:
-    explicit ShareToFacebookDialog(Session *session, QSharedPointer<VideoItem> video, QWidget *parent = 0);
+    explicit ShareToFacebookDialog(QSharedPointer<VideoItem> video, QWidget *parent = 0);
     
 private:
     void setLandscapeLayout();
@@ -26,7 +26,6 @@ private slots:
     void shareVideo();
     
 private:
-    Session *m_session;
     QSharedPointer<VideoItem> m_video;
     QLineEdit *m_titleEdit;
     QTextEdit *m_descriptionEdit;
