@@ -6,6 +6,7 @@
 #include <QScrollArea>
 #include <QLineEdit>
 #include <QCheckBox>
+#include <QMaemo5Style>
 
 TransferDetailsDialog::TransferDetailsDialog(QSharedPointer<TransferItem> transfer, QWidget *parent) :
     AbstractDialog(parent),
@@ -188,7 +189,7 @@ void TransferDetailsDialog::onTransferProgressChanged(int progress) {
 }
 
 void TransferDetailsDialog::onTransferSpeedChanged(int speed) {
-    m_speedLabel->setText(QString("<font color='#4d4d4d'>%1/s</font>").arg(Utils::fileSizeFromBytes(speed)));
+    m_speedLabel->setText(QString("<font color='%1'>%2/s</font>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(Utils::fileSizeFromBytes(speed)));
 }
 
 void TransferDetailsDialog::onFileNameTextChanged(const QString &text) {
