@@ -14,8 +14,9 @@ class QModelIndex;
 class TransferListWindow : public StackedWindow
 {
     Q_OBJECT
+
 public:
-    explicit TransferListWindow(Session *session, QWidget *parent);
+    explicit TransferListWindow(QWidget *parent);
     ~TransferListWindow();
 
 private:
